@@ -18,6 +18,7 @@ class ErrorCodes(object):
         FirstNameIsTooLong = "81805"
         LastNameIsTooLong = "81806"
         LocalityIsTooLong = "81807"
+        PostalCodeInvalidCharacters = "81813"
         PostalCodeIsRequired = "81808"
         PostalCodeIsTooLong = "81809"
         RegionIsTooLong = "81810"
@@ -91,6 +92,7 @@ class ErrorCodes(object):
         CreditCardIsRequired = "91508"
         CustomerDefaultPaymentMethodCardTypeIsNotAccepted = "81509"
         CustomFieldIsInvalid = "91526"
+        CustomFieldIsTooLong = "81527"
         CustomerIdIsInvalid = "91510"
         CustomerDoesNotHaveCreditCard = "91511"
         HasAlreadyBeenRefunded = "91512"
@@ -99,10 +101,15 @@ class ErrorCodes(object):
         OrderIdIsTooLong = "91501"
         PaymentMethodConflict = "91515"
         PaymentMethodDoesNotBelongToCustomer = "91516"
+        PaymentMethodDoesNotBelongToSubscription = "91527"
         PaymentMethodTokenCardTypeIsNotAccepted = "91517"
         PaymentMethodTokenIsInvalid = "91518"
+        ProcessorAuthorizationCodeCannotBeSet = "91519"
+        ProcessorAuthorizationCodeIsInvalid = "81520"
         RefundAmountIsTooLarge = "91521"
         SettlementAmountIsTooLarge = "91522"
+        SubscriptionDoesNotBelongToCustomer = "91529"
+        SubscriptionIdIsInvalid = "91528"
         TypeIsInvalid = "91523"
         TypeIsRequired = "91524"
 
